CREATE SCHEMA Kataster

-- Historie:
--
-- 02.08.2006 - 1.011
-- Einfhrung OKSTRA-ID gem N0073
-- Einfhrung des Schemas Liegenschaftsverwaltung gem N0080
-- 
-- 09.09.2005 - 1.010 (1.010)
-- Formale Versionierung
--
-- 29.06.2004 - 1.002 (1.009)
-- berarbeitung gem Dokument N0060
--
-- 31.05.2002 - 1.001 (1.007)
-- Erweiterung der Wertebereiche von Meter, Kilometer und Jahr
--
-- 12.09.2001 - 1.000 (1.004)
-- Schema Kataster in den OKSTRA aufgenommen

CREATE TABLE Flurstueck (
   Flurstueck_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Flurstueck_ID) REFERENCES Geometrieschema.Flaechenobjekt_Modell,
   FOREIGN KEY (Flurstueck_ID) REFERENCES Flurstueck_abstrakt,
   Flurstueck_Zaehler
      VARCHAR(255) NOT NULL,
   Flurstueck_Nenner
      VARCHAR(255),
   Flaeche
      REAL, -- Quadratmeter
   CHECK ( Flaeche >= 0 ),
   Lage
      VARCHAR(255),
   Baukilometer
      REAL, -- Kilometer
   Liegenschaftsbuch
      VARCHAR(255),
   Flurkarte
      VARCHAR(255),
   Bemerkung
      VARCHAR(255),
   Geloescht
      INTEGER REFERENCES Logical_Types.Boolean,
   in_Gemarkung
      INTEGER NOT NULL REFERENCES Gemarkung,
   in_Flur
      INTEGER REFERENCES Flur,
   hat_LV_Flurstuecksdetails
      INTEGER REFERENCES Liegenschaftsverwaltung.LV_Flurstuecksdetails
)

CREATE TABLE Flurstueck__liegt_auf_Nutzfl (
   Flurstueck
      INTEGER NOT NULL REFERENCES Flurstueck,
   Nutzungsartflaeche
      INTEGER NOT NULL REFERENCES Grunderwerb.Nutzungsartflaeche
)

CREATE TABLE Flurstueck__Nachfolger_Flstk (
   Flurstueck
      INTEGER NOT NULL REFERENCES Flurstueck,
   Flurstueck_abstrakt
      INTEGER NOT NULL REFERENCES Flurstueck_abstrakt
)

CREATE TABLE Flurstueck__Vorgaenger_Flstk (
   Flurstueck
      INTEGER NOT NULL REFERENCES Flurstueck,
   Flurstueck_abstrakt
      INTEGER NOT NULL REFERENCES Flurstueck_abstrakt
)

CREATE TABLE Flurstueck_abstrakt (
   Flurstueck_abstrakt_ID
      INTEGER NOT NULL PRIMARY KEY,
   OKSTRA_ID
      CHAR(32), -- GUID
   Art_Flurstueck_abstrakt
      INTEGER NOT NULL REFERENCES Art_Flurstueck_abstrakt
)

CREATE TABLE Art_Flurstueck_abstrakt (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(17) NOT NULL
)

INSERT INTO Art_Flurstueck_abstrakt VALUES ( 30001,'Flurstueck')
INSERT INTO Art_Flurstueck_abstrakt VALUES ( 30010,'Flurstueck_Symbol')

CREATE TABLE Flurstueck_Symbol (
   Flurstueck_Symbol_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Flurstueck_Symbol_ID) REFERENCES Flurstueck_abstrakt,
   Kennung
      VARCHAR(20) NOT NULL
)

CREATE TABLE Flur (
   Flur_ID
      INTEGER NOT NULL PRIMARY KEY,
   OKSTRA_ID
      CHAR(32), -- GUID
   Kennung
      VARCHAR(255) NOT NULL
)

CREATE TABLE besondere_Flurstuecksgrenze (
   besondere_Flurstuecksgrenze_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (besondere_Flurstuecksgrenze_ID) REFERENCES Geometrieschema.Linienobjekt_Modell
)

CREATE TABLE Grenzpunkt (
   Grenzpunkt_ID
      INTEGER NOT NULL PRIMARY KEY,
   OKSTRA_ID
      CHAR(32) -- GUID
)

CREATE TABLE Grenzpunkt__ist_Vermessungspkt (
   Grenzpunkt
      INTEGER NOT NULL REFERENCES Grenzpunkt,
   Vermessungspunkt
      INTEGER NOT NULL REFERENCES Vermessungspunkt.Vermessungspunkt
)

CREATE TABLE Gemarkung (
   Gemarkung_ID
      INTEGER NOT NULL PRIMARY KEY,
   OKSTRA_ID
      CHAR(32), -- GUID
   Schluessel
      VARCHAR(255) NOT NULL
)

CREATE TABLE Gemarkung__in_Verwaltungsbez (
   Gemarkung
      INTEGER NOT NULL REFERENCES Gemarkung,
   Verwaltungsbezirk_abstrakt
      INTEGER NOT NULL REFERENCES Administration.Verwaltungsbezirk_abstrakt
)

CREATE TABLE ALKIS_Objekt (
   ALKIS_Objekt_ID
      INTEGER NOT NULL PRIMARY KEY,
   OKSTRA_ID
      CHAR(32), -- GUID
   Identifikator
      VARCHAR(255) NOT NULL
)

CREATE TABLE ALKIS_Objekt_Punkt (
   ALKIS_Objekt_Punkt_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (ALKIS_Objekt_Punkt_ID) REFERENCES Geometrieschema.Punktobjekt_Modell,
   FOREIGN KEY (ALKIS_Objekt_Punkt_ID) REFERENCES Entwurf.allgemeine_Eigenschaften,
   FOREIGN KEY (ALKIS_Objekt_Punkt_ID) REFERENCES ALKIS_Objekt
)

CREATE TABLE ALKIS_Objekt_Linie (
   ALKIS_Objekt_Linie_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (ALKIS_Objekt_Linie_ID) REFERENCES Geometrieschema.Linienobjekt_Modell,
   FOREIGN KEY (ALKIS_Objekt_Linie_ID) REFERENCES Entwurf.allgemeine_Eigenschaften,
   FOREIGN KEY (ALKIS_Objekt_Linie_ID) REFERENCES ALKIS_Objekt
)

CREATE TABLE ALKIS_Objekt_Flaeche (
   ALKIS_Objekt_Flaeche_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (ALKIS_Objekt_Flaeche_ID) REFERENCES Geometrieschema.Flaechenobjekt_Modell,
   FOREIGN KEY (ALKIS_Objekt_Flaeche_ID) REFERENCES Entwurf.allgemeine_Eigenschaften,
   FOREIGN KEY (ALKIS_Objekt_Flaeche_ID) REFERENCES ALKIS_Objekt
)

