CREATE SCHEMA Topografie

-- Historie:
--
-- 02.08.2006 - 1.011
-- Ergnzung von RAS-Verm-Objekten gem N0071
-- Einfhrung OKSTRA-ID gem N0073
--
-- 09.09.2005 - 1.010 (1.010)
-- Schema Topografie erstellt

CREATE TABLE Bestandsstatus (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Bestandsstatus VALUES (1,'Bestand_erfasst')
INSERT INTO Bestandsstatus VALUES (2,'Bestand_amtlich')
INSERT INTO Bestandsstatus VALUES (3,'geplant/neu')
INSERT INTO Bestandsstatus VALUES (4,'geplant/Abriss')
INSERT INTO Bestandsstatus VALUES (5,'zerstrt')
INSERT INTO Bestandsstatus VALUES (6,'unbekannt')

CREATE TABLE Boeschung (
   Boeschung_ID
      INTEGER NOT NULL PRIMARY KEY,
   OKSTRA_ID
      CHAR(32), -- GUID
   Bestandsstatus
      INTEGER NOT NULL REFERENCES Bestandsstatus,   
   FOREIGN KEY (Boeschung_ID) REFERENCES Geometrieschema.Flaechenobjekt_Modell,
   Art_Boeschung
      INTEGER NOT NULL REFERENCES Art_Boeschung,
   Hoehe
      REAL, -- Meter
   Beginn_Interpolation
      INTEGER NOT NULL REFERENCES Beginn_Interpolation
)

CREATE TABLE Boeschung__hat_Oberkante (
   Boeschung
      INTEGER NOT NULL REFERENCES Boeschung,
   Boeschungskantenabschnitt
      INTEGER NOT NULL REFERENCES Boeschungskantenabschnitt,
   folgt_auf_Boeschkantenabschn
      INTEGER REFERENCES Boeschungskantenabschnitt
)

CREATE TABLE Boeschung__hat_Unterkante (
   Boeschung
      INTEGER NOT NULL REFERENCES Boeschung,
   Boeschungskantenabschnitt
      INTEGER NOT NULL REFERENCES Boeschungskantenabschnitt,
   folgt_auf_Boeschkantenabschn
      INTEGER REFERENCES Boeschungskantenabschnitt
)

CREATE TABLE Art_Boeschung (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Art_Boeschung VALUES (1,'normale Bschung')
INSERT INTO Art_Boeschung VALUES (2,'historische Bschung')
INSERT INTO Art_Boeschung VALUES (3,'Berme')

CREATE TABLE Beginn_Interpolation (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Beginn_Interpolation VALUES (1,'Anfang')
INSERT INTO Beginn_Interpolation VALUES (2,'Ende')
INSERT INTO Beginn_Interpolation VALUES (3,'nicht festgelegt')

CREATE TABLE Boeschungskantenabschnitt (
   Boeschungskantenabschnitt_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Boeschungskantenabschnitt_ID) REFERENCES Geometrieschema.Linienobjekt_Modell,
   sicher
      INTEGER REFERENCES Logical_Types.Boolean
)

CREATE TABLE Boeschungslinie (
   Boeschungslinie_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Boeschungslinie_ID) REFERENCES Geometrieschema.Linienobjekt_Modell,
   Art_Boeschungslinie
      INTEGER NOT NULL REFERENCES Art_Boeschungslinie,
   gehoert_zu_Boeschung
      INTEGER NOT NULL REFERENCES Boeschung
)

CREATE TABLE Art_Boeschungslinie (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Art_Boeschungslinie VALUES (1,'Gefllewechsel')
INSERT INTO Art_Boeschungslinie VALUES (2,'Kehle')

CREATE TABLE Gebaeude (
   Gebaeude_ID
      INTEGER NOT NULL PRIMARY KEY,
   OKSTRA_ID
      CHAR(32), -- GUID
   Bestandsstatus
      INTEGER NOT NULL REFERENCES Bestandsstatus,      
   FOREIGN KEY (Gebaeude_ID) REFERENCES Geometrieschema.Linienobjekt_Modell,
   FOREIGN KEY (Gebaeude_ID) REFERENCES Geometrieschema.Flaechenobjekt_Modell,
   Gebaeudenutzung
      INTEGER NOT NULL REFERENCES Gebaeudenutzung,
   Gebaeudefunktion
      INTEGER REFERENCES Gebaeudefunktion,
   Name
      VARCHAR(255),
   Traufhoehe
      REAL, -- Meter
   Firsthoehe
      REAL, -- Meter
   hat_Erfassungsqualitaet
      INTEGER REFERENCES Allgemeine_Objekte.Erfassungsqualitaet
)

CREATE TABLE Gebaeude__hat_Anschrift (
   Gebaeude
      INTEGER NOT NULL REFERENCES Gebaeude,
   Anschrift
      INTEGER NOT NULL REFERENCES Anschrift
)

CREATE TABLE Gebaeude__hat_Geschoss (
   Gebaeude
      INTEGER NOT NULL REFERENCES Gebaeude,
   Geschoss
      INTEGER NOT NULL REFERENCES Geschoss,
   folgt_auf_Geschoss
      INTEGER REFERENCES Geschoss
)

CREATE TABLE Gebaeudenutzung (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

CREATE TABLE Gebaeudefunktion (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

CREATE TABLE Anschrift (
   Anschrift_ID
      INTEGER NOT NULL PRIMARY KEY,
   OKSTRA_ID
      CHAR(32), -- GUID
   Hausnummer
      VARCHAR(255),
   Strassenname
      VARCHAR(255)
)

CREATE TABLE Geschoss (
   Geschoss_ID
      INTEGER NOT NULL PRIMARY KEY,
   OKSTRA_ID
      CHAR(32), -- GUID
   Hoehe
      REAL, -- Meter
   Oberkante_Fenster
      REAL, -- Meter
   Bezeichnung
      VARCHAR(255),
   von_Gebaeude
      INTEGER NOT NULL REFERENCES Gebaeude
)

CREATE TABLE Zaun (
   Zaun_ID
      INTEGER NOT NULL PRIMARY KEY,
   OKSTRA_ID
      CHAR(32), -- GUID
   Bestandsstatus
      INTEGER NOT NULL REFERENCES Bestandsstatus,      
   FOREIGN KEY (Zaun_ID) REFERENCES Geometrieschema.Linienobjekt_Modell,
   Hoehe
      REAL, -- Meter
   wahre_Laenge
      REAL, -- Meter
   Fundament_vorhanden
      INTEGER REFERENCES Logical_Types.Boolean,
   Seite_Zaunpfaehle
      CHAR(1) REFERENCES Seite_Zaunpfaehle,
   Zaunart
      INTEGER REFERENCES Zaunart,
   Material_Zaunpfaehle
      INTEGER REFERENCES Material_Zaunpfaehle,
   Zaunfunktion
      INTEGER REFERENCES Zaunfunktion
)

CREATE TABLE Seite_Zaunpfaehle (
   Kennung
      CHAR(1) NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Seite_Zaunpfaehle VALUES ('L','links')
INSERT INTO Seite_Zaunpfaehle VALUES ('R','rechts')

CREATE TABLE Zaunart (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Zaunart VALUES (1,'Holzzaun')
INSERT INTO Zaunart VALUES (2,'Drahtzaun')
INSERT INTO Zaunart VALUES (3,'Metallzaun')

CREATE TABLE Material_Zaunpfaehle (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Material_Zaunpfaehle VALUES (1,'Zement')
INSERT INTO Material_Zaunpfaehle VALUES (2,'Metall')
INSERT INTO Material_Zaunpfaehle VALUES (3,'Holz')

CREATE TABLE Zaunfunktion (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Zaunfunktion VALUES (1,'Wildschutzzaun')
INSERT INTO Zaunfunktion VALUES (2,'Kleintierschutzzaun')
INSERT INTO Zaunfunktion VALUES (3,'Amphibienschutzzaun')
INSERT INTO Zaunfunktion VALUES (4,'Bauschutzzaun')
INSERT INTO Zaunfunktion VALUES (5,'Weidezaun')
INSERT INTO Zaunfunktion VALUES (6,'Grenzzaun')

CREATE TABLE Oeffnung (
   Oeffnung_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Oeffnung_ID) REFERENCES Geometrieschema.Punktobjekt_Modell,
   Art_Oeffnung
      INTEGER NOT NULL REFERENCES Art_Oeffnung,
   von_Zaun
      INTEGER REFERENCES Zaun,
   von_Mauerabschnitt
      INTEGER REFERENCES Mauerabschnitt,
   von_Heckenabschnitt
      INTEGER REFERENCES Heckenabschnitt
)

CREATE TABLE Art_Oeffnung (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Art_Oeffnung VALUES (1,'Viehdurchlass')
INSERT INTO Art_Oeffnung VALUES (2,'Tr')
INSERT INTO Art_Oeffnung VALUES (3,'Tor')
INSERT INTO Art_Oeffnung VALUES (4,'Fluchttr')
INSERT INTO Art_Oeffnung VALUES (5,'offener Durchlass')

CREATE TABLE Mauer (
   Mauer_ID
      INTEGER NOT NULL PRIMARY KEY,
   OKSTRA_ID
      CHAR(32), -- GUID
   Bestandsstatus
      INTEGER NOT NULL REFERENCES Bestandsstatus,      
   Mauerfunktion
      INTEGER REFERENCES Mauerfunktion
)

CREATE TABLE Mauer__hat_Mauerabschnitt (
   Mauer
      INTEGER NOT NULL REFERENCES Mauer,
   Mauerabschnitt
      INTEGER NOT NULL REFERENCES Mauerabschnitt,
   folgt_auf_Mauerabschnitt
      INTEGER REFERENCES Mauerabschnitt
)

CREATE TABLE Mauerfunktion (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Mauerfunktion VALUES (1,'Grenzmauer')
INSERT INTO Mauerfunktion VALUES (2,'Sttzmauer')
INSERT INTO Mauerfunktion VALUES (3,'Grenz- und Sttzmauer')

CREATE TABLE Mauerabschnitt (
   Mauerabschnitt_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Mauerabschnitt_ID) REFERENCES Geometrieschema.Linienobjekt_Modell,
   Breite
      REAL NOT NULL, -- Zentimeter
   CHECK ( Breite >= 0 ),
   Hoehe
      REAL NOT NULL, -- Meter
   wahre_Laenge
      REAL, -- Meter
   ist_Pfeiler
      INTEGER REFERENCES Logical_Types.Boolean,
   Material_Mauerabschnitt
      INTEGER REFERENCES Material_Mauerabschnitt,
   Lage_Bezugsgeometrie
      CHAR(1) REFERENCES Lage_Bezugsgeometrie,
   hat_Zaun
      INTEGER REFERENCES Zaun,
   gehoert_zu_Mauer
      INTEGER NOT NULL REFERENCES Mauer
)

CREATE TABLE Lage_Bezugsgeometrie (
   Kennung
      CHAR(1) NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Lage_Bezugsgeometrie VALUES ('L','linke Seite')
INSERT INTO Lage_Bezugsgeometrie VALUES ('R','rechte Seite')
INSERT INTO Lage_Bezugsgeometrie VALUES ('M','Mitte')

CREATE TABLE Material_Mauerabschnitt (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

CREATE TABLE Gehoelz (
   Gehoelz_ID
      INTEGER NOT NULL PRIMARY KEY,
   OKSTRA_ID
      CHAR(32), -- GUID
   Bestandsstatus
      INTEGER NOT NULL REFERENCES Bestandsstatus,      
   Gehoelzart
      INTEGER REFERENCES Gehoelzart
)

CREATE TABLE Gehoelzart (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

CREATE TABLE Gebuesch (
   Gebuesch_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Gebuesch_ID) REFERENCES Gehoelz,
   FOREIGN KEY (Gebuesch_ID) REFERENCES Geometrieschema.Flaechenobjekt_Modell
)

CREATE TABLE Hecke (
   Hecke_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Hecke_ID) REFERENCES Gehoelz,
   Heckenfunktion
      INTEGER REFERENCES Heckenfunktion
)

CREATE TABLE Hecke__hat_Heckenabschnitt (
   Hecke
      INTEGER NOT NULL REFERENCES Hecke,
   Heckenabschnitt
      INTEGER NOT NULL REFERENCES Heckenabschnitt,
   folgt_auf_Heckenabschnitt
      INTEGER REFERENCES Heckenabschnitt
)

CREATE TABLE Heckenfunktion (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Heckenfunktion VALUES (1,'Grenzhecke')
INSERT INTO Heckenfunktion VALUES (2,'Sichtschutz')

CREATE TABLE Heckenabschnitt (
   Heckenabschnitt_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Heckenabschnitt_ID) REFERENCES Geometrieschema.Linienobjekt_Modell,
   Breite
      REAL NOT NULL, -- Zentimeter
   CHECK ( Breite >= 0 ),
   Hoehe
      REAL, -- Meter
   wahre_Laenge
      REAL, -- Meter
   gehoert_zu_Hecke
      INTEGER NOT NULL REFERENCES Hecke
)

